@@ -6,19 +6,19 @@ Exclude imports from linters due to install aliases breaking the rules.
 import datetime
 import json
 import time
-from uuid import UUID
 from builtins import str as text  # noqa
 from urllib.parse import parse_qs, urljoin, urlparse
+from uuid import UUID
 
 from pydantic import BaseModel
 
-from requests import (  # pylint: disable=W0622
+from requests import (
     ConnectTimeout,
-    ConnectionError,
     ReadTimeout,
+    delete,
     get,
     post,
-)
+)  # noqa: I201
 
 from gencove import constants  # noqa: I100
 from gencove.constants import (
@@ -29,18 +29,26 @@ from gencove.constants import (
     SampleStatus,
     SortOrder,
 )
+from gencove.exceptions import MaintenanceError
 from gencove.logger import echo_debug
-from gencove.models import (
+from gencove.models import (  # noqa: I101
     AccessJWT,
+    BaseSpaceBiosample,
+    BaseSpaceProject,
+    BaseSpaceProjectImport,
     BatchDetail,
     CreateJWT,
+    FileTypesModel,
+    ImportExistingSamplesModel,
     PipelineCapabilities,
     Project,
-    ProjectBatchTypes,
     ProjectBatches,
+    ProjectBatchTypes,
     ProjectMergeVCFs,
-    ProjectSamples,
     Projects,
+    ProjectSamples,
+    S3AutoimportTopic,
+    S3ProjectImport,
     SampleDetails,
     SampleMetadata,
     SampleQC,
@@ -131,7 +139,7 @@ class APIClient:
         return json.dumps(payload, cls=CustomEncoder)
 
     # pylint: disable=bad-option-value,bad-continuation,too-many-arguments
-    # pylint: disable=too-many-branches
+    # pylint: disable=too-many-branches,too-many-locals, too-many-statements
     def _request(
         self,
         endpoint="",
@@ -140,6 +148,7 @@ class APIClient:
         custom_headers=None,
         timeout=60,
         sensitive=False,
+        raw_response=False,
     ):
         url = urljoin(text(self.host), text(endpoint))
         headers = {
@@ -154,16 +163,21 @@ class APIClient:
             params = {}
 
         echo_debug(
-            "Contacting url: {} with payload: {}".format(
-                url, "[SENSITIVE CONTENT]" if sensitive else params
-            )
+            f"Contacting url: {url} with payload: "
+            f"{'[SENSITIVE CONTENT]' if sensitive else params}"
         )
         start = time.time()
 
         try:
             if method == "get":
-                response = get(
-                    url=url, params=params, headers=headers, timeout=timeout
+                response = get(url=url, params=params, headers=headers, timeout=timeout)
+            elif method == "delete":
+                post_payload = APIClient._serialize_post_payload(params)
+                response = delete(
+                    url=url,
+                    data=post_payload,
+                    headers=headers,
+                    timeout=timeout,
                 )
             else:
                 post_payload = APIClient._serialize_post_payload(params)
@@ -189,45 +203,49 @@ class APIClient:
             )
 
         echo_debug(
-            "API response is {} status is {} in {}ms".format(
-                "[SENSITIVE CONTENT]" if sensitive else response.content,
-                response.status_code,
-                (time.time() - start) * 1000,
-            )
+            f"API response "
+            f"is {'[SENSITIVE CONTENT]' if sensitive else response.content} "
+            f"status is {response.status_code} in {(time.time() - start) * 1000}ms"
         )
 
         # pylint: disable=no-member
         if response.status_code >= 200 and response.status_code < 300:
-            return response.json() if response.text else {}
+            content = response.text
+            if not raw_response:
+                content = response.json() if content else {}
+            return content
 
         http_error_msg = ""
         if 400 <= response.status_code < 500:
-            http_error_msg = "API Client Error: {}".format(response.reason)
+            http_error_msg = f"API Client Error: {response.reason}"
             if response.text:
                 response_json = response.json()
                 if "detail" in response_json:
-                    http_error_msg += ": {}".format(response_json["detail"])
+                    http_error_msg += f": {response_json['detail']}"
                 else:
                     try:
                         error_msg = "\n".join(
                             [
                                 # create-batch can return error details that
                                 # is a dict, not a list
-                                "  {}: {}".format(
-                                    key,
-                                    value[0]
-                                    if isinstance(value, list)
-                                    else str(value),
-                                )
+                                f"  {key}: {value[0] if isinstance(value, list) else str(value)}"  # noqa: E501  # pylint: disable=line-too-long
                                 for key, value in response_json.items()
                             ]
                         )
                     except AttributeError:
                         error_msg = "\n".join(response_json)
-                    http_error_msg += ":\n{}".format(error_msg)
+                    http_error_msg += f":\n{error_msg}"
 
         elif 500 <= response.status_code < 600:
-            http_error_msg = "Server Error: {}".format(response.reason)
+            http_error_msg = "Server Error: {response.reason}"
+            if response.status_code == 503:
+                if response.text:
+                    response_json = response.json()
+                    if "maintenance" in response_json:
+                        raise MaintenanceError(
+                            message=response_json["maintenance_message"],
+                            eta=response_json["maintenance_eta"],
+                        )
 
         raise APIClientError(http_error_msg, response.status_code)
 
@@ -243,8 +261,46 @@ class APIClient:
 
     def _get_authorization(self):
         if self._api_key:
-            return {"Authorization": "Api-Key {}".format(self._api_key)}
-        return {"Authorization": "Bearer {}".format(self._jwt_token)}
+            return {"Authorization": f"Api-Key {self._api_key}"}
+        return {"Authorization": f"Bearer {self._jwt_token}"}
+
+    def _delete(
+        self,
+        endpoint,
+        payload=None,
+        timeout=120,
+        authorized=False,
+        sensitive=False,
+        refreshed=False,
+        model=None,
+    ):
+        headers = {} if not authorized else self._get_authorization()
+        try:
+            response = self._request(
+                endpoint,
+                params=payload,
+                method="delete",
+                timeout=timeout,
+                custom_headers=headers,
+                sensitive=sensitive,
+            )
+            if model:
+                return model(**response)
+            return response
+        except APIClientError as err:
+            if not refreshed and self._jwt_refresh_token and err.status_code == 401:
+                self._refresh_authentication()
+                return self._delete(
+                    endpoint,
+                    payload,
+                    timeout,
+                    authorized,
+                    sensitive,
+                    True,
+                    model,
+                )
+
+            raise err
 
     def _post(
         self,
@@ -270,7 +326,7 @@ class APIClient:
                 return model(**response)
             return response
         except APIClientError as err:
-            if not refreshed and err.status_code and err.status_code == 401:
+            if not refreshed and self._jwt_refresh_token and err.status_code == 401:
                 self._refresh_authentication()
                 return self._post(
                     endpoint,
@@ -293,6 +349,7 @@ class APIClient:
         sensitive=False,
         refreshed=False,
         model=None,
+        raw_response=False,
     ):
         headers = {} if not authorized else self._get_authorization()
         try:
@@ -303,6 +360,7 @@ class APIClient:
                 timeout=timeout,
                 custom_headers=headers,
                 sensitive=sensitive,
+                raw_response=raw_response,
             )
             if model:
                 return model(**response)
@@ -328,9 +386,7 @@ class APIClient:
             query_params = {}
         query_params.update({"offset": 0, "limit": limit})
         if next_link:
-            query_params["offset"] = parse_qs(urlparse(next_link).query)[
-                "offset"
-            ]
+            query_params["offset"] = parse_qs(urlparse(next_link).query)["offset"]
         return query_params
 
     def set_api_key(self, api_key):
@@ -346,18 +402,21 @@ class APIClient:
             model=AccessJWT,
         )
 
-    def get_jwt(self, email, password):
+    def get_jwt(self, email, password, otp_token):
         """Get jwt token."""
+        body = {"email": email, "password": password}
+        if otp_token is not None:
+            body["otp_token"] = otp_token
         return self._post(
             self.endpoints.GET_JWT.value,
-            dict(email=email, password=password),
+            body,
             sensitive=True,
             model=CreateJWT,
         )
 
-    def login(self, email, password):
+    def login(self, email, password, otp_token=None):
         """Log user in."""
-        jwt = self.get_jwt(email, password)
+        jwt = self.get_jwt(email, password, otp_token)
         self._set_jwt(jwt.access, jwt.refresh)
 
     def get_upload_details(self, gncv_file_path):
@@ -395,9 +454,7 @@ class APIClient:
         sort_order=SortOrder.DESC.value,
     ):
         """List single project's associated samples."""
-        project_endpoint = self.endpoints.PROJECT_SAMPLES.value.format(
-            id=project_id
-        )
+        project_endpoint = self.endpoints.PROJECT_SAMPLES.value.format(id=project_id)
         params = self._add_query_params(
             next_link,
             {
@@ -421,7 +478,7 @@ class APIClient:
         Args:
             samples (list of dicts): sample sheet results
             project_id (str): project to which to assign the samples
-            metadata (str): JSON metadata to be applied to all samples
+            metadata (str): Optional JSON metadata to be applied to all samples
         """
         payload = {"uploads": samples, "metadata": metadata}
 
@@ -453,6 +510,12 @@ class APIClient:
             self.endpoints.SAMPLE_QC_METRICS.value.format(id=sample_id),
             authorized=True,
             model=SampleQC,
+            # get max number of items on a single page; a quick fix that avoids
+            # paginating through the results for the time being
+            query_params={
+                "offset": 0,
+                "limit": 200,
+            },
         )
 
     def get_sample_sheet(
@@ -547,9 +610,7 @@ class APIClient:
 
     def get_project_batches(self, project_id, next_link=None):
         """List single project's batches."""
-        project_endpoint = self.endpoints.PROJECT_BATCHES.value.format(
-            id=project_id
-        )
+        project_endpoint = self.endpoints.PROJECT_BATCHES.value.format(id=project_id)
         params = self._add_query_params(next_link)
         return self._get(
             project_endpoint,
@@ -558,13 +619,9 @@ class APIClient:
             model=ProjectBatches,
         )
 
-    def create_project_batch(
-        self, project_id, batch_type, batch_name, sample_ids
-    ):
+    def create_project_batch(self, project_id, batch_type, batch_name, sample_ids):
         """Making a post request to create project batch."""
-        project_endpoint = self.endpoints.PROJECT_BATCHES.value.format(
-            id=project_id
-        )
+        project_endpoint = self.endpoints.PROJECT_BATCHES.value.format(id=project_id)
 
         payload = {
             "name": batch_name,
@@ -589,9 +646,7 @@ class APIClient:
 
         payload = {"sample_ids": sample_ids}
 
-        return self._post(
-            restore_project_samples_endpoint, payload, authorized=True
-        )
+        return self._post(restore_project_samples_endpoint, payload, authorized=True)
 
     def get_project(self, project_id):
         """Get single project."""
@@ -603,23 +658,19 @@ class APIClient:
         merge_vcf_endpoint = self.endpoints.PROJECT_MERGE_VCFS.value.format(
             id=project_id
         )
-        return self._post(
-            merge_vcf_endpoint, authorized=True, model=ProjectMergeVCFs
-        )
+        return self._post(merge_vcf_endpoint, authorized=True, model=ProjectMergeVCFs)
 
     def retrieve_merged_vcf(self, project_id):
         """Retrieve the status of the merge command for a project."""
         merge_vcf_endpoint = self.endpoints.PROJECT_MERGE_VCFS.value.format(
             id=project_id
         )
-        return self._get(
-            merge_vcf_endpoint, authorized=True, model=ProjectMergeVCFs
-        )
+        return self._get(merge_vcf_endpoint, authorized=True, model=ProjectMergeVCFs)
 
     def get_metadata(self, sample_id):
         """Retrieve the metadata for a sample."""
-        sample_metadata_endpoint = (
-            self.endpoints.SAMPLE_METADATA.value.format(id=sample_id)
+        sample_metadata_endpoint = self.endpoints.SAMPLE_METADATA.value.format(
+            id=sample_id
         )
         return self._get(
             sample_metadata_endpoint, authorized=True, model=SampleMetadata
@@ -627,8 +678,8 @@ class APIClient:
 
     def set_metadata(self, sample_id, metadata):
         """Assign the metadata to a sample."""
-        sample_metadata_endpoint = (
-            self.endpoints.SAMPLE_METADATA.value.format(id=sample_id)
+        sample_metadata_endpoint = self.endpoints.SAMPLE_METADATA.value.format(
+            id=sample_id
         )
         payload = {
             "metadata": metadata,
@@ -639,3 +690,276 @@ class APIClient:
             authorized=True,
             model=SampleMetadata,
         )
+
+    def import_basespace_projects(
+        self, basespace_project_ids, project_id, metadata=None
+    ):
+        """Make a request to import Biosamples from BaseSpace projects to
+        a given project.
+
+        Args:
+            basespace_project_ids (list of strings): BaseSpace projects
+            project_id (str): project to which to assign the samples
+            metadata (str): Optional JSON metadata to be applied to all samples
+        """
+
+        payload = {
+            "basespace_project_ids": basespace_project_ids,
+            "project_id": project_id,
+            "metadata": metadata,
+        }
+
+        return self._post(
+            self.endpoints.BASESPACE_PROJECTS_IMPORT.value,
+            payload,
+            authorized=True,
+        )
+
+    def list_basespace_projects(self, next_link=None):
+        """Make a request to list BaseSpace projects.
+
+        Args:
+            next_link (str, optional): url from previous
+                response['meta']['next'].
+
+        Returns:
+            api response (dict):
+                {
+                    "meta": {
+                        "count": int,
+                        "next": str,
+                        "previous": optional[str],
+                    },
+                    "results": [...]
+                }
+        """
+        params = self._add_query_params(next_link)
+        return self._get(
+            self.endpoints.BASESPACE_PROJECTS_LIST.value,
+            query_params=params,
+            authorized=True,
+            model=BaseSpaceProject,
+        )
+
+    def list_biosamples(self, basespace_project_id, next_link=None):
+        """Make a request to list Biosamples from a BaseSpace project.
+
+        Args:
+            basespace_project_id (str): what BaseSpace project to request
+                Biosamples from
+            next_link (str, optional): url from previous
+                response['meta']['next'].
+
+        Returns:
+            api response (dict):
+                {
+                    "meta": {
+                        "count": int,
+                        "next": str,
+                        "previous": optional[str],
+                    },
+                    "results": [...]
+                }
+        """
+        params = self._add_query_params(next_link)
+        return self._get(
+            self.endpoints.BASESPACE_BIOSAMPLES_LIST.value.format(
+                id=basespace_project_id
+            ),
+            query_params=params,
+            authorized=True,
+            model=BaseSpaceBiosample,
+        )
+
+    def s3_uri_import(self, s3_uri, project_id, metadata=None):
+        """Make a request to import samples from S3 URI to a given
+        project.
+
+        Args:
+            s3_uri (str): s3 path formated as s3://<bucket-name>/prefix
+            project_id (str): project to which to assign the samples
+            metadata (str): Optional JSON metadata to be applied to all samples
+        """
+
+        payload = {
+            "s3_uri": s3_uri,
+            "project_id": project_id,
+            "metadata": metadata,
+        }
+
+        return self._post(
+            self.endpoints.S3_URI_IMPORT.value,
+            payload,
+            authorized=True,
+        )
+
+    def autoimport_from_basespace(
+        self,
+        project_id,
+        identifier,
+        metadata=None,
+    ):
+        """Make a request to create a periodic import job of BaseSpace
+        projects' Biosamples to a given Gencove project.
+
+        Args:
+            project_id (str): project to which to assign the samples
+            identifier (str): identifier that is contained in BaseSpace
+                projects' name
+            metadata (str): Optional JSON metadata to be applied to all samples
+        """
+        payload = {
+            "project_id": project_id,
+            "identifier": identifier,
+            "metadata": metadata,
+        }
+
+        return self._post(
+            self.endpoints.BASESPACE_PROJECTS_AUTOIMPORT.value,
+            payload,
+            authorized=True,
+        )
+
+    def list_basespace_autoimport_jobs(self, next_link=None):
+        """Make a request to list periodic import jobs of BaseSpace projects'
+        Biosamples.
+
+        Args:
+            next_link (str, optional): url from previous
+                response['meta']['next'].
+
+        Returns:
+            api response (dict):
+                {
+                    "meta": {
+                        "count": int,
+                        "next": str,
+                        "previous": optional[str],
+                    },
+                    "results": [...]
+                }
+        """
+
+        params = self._add_query_params(next_link)
+        return self._get(
+            self.endpoints.BASESPACE_PROJECTS_AUTOIMPORT.value,
+            query_params=params,
+            authorized=True,
+            model=BaseSpaceProjectImport,
+        )
+
+    def autoimport_from_s3(
+        self,
+        project_id,
+        s3_uri,
+        metadata=None,
+    ):
+        """Make a request to create an import job of S3 URI to a given
+        Gencove project.
+
+        Args:
+            s3_uri (str): s3 path formated as s3://<bucket-name>/prefix
+            project_id (str): project to which to assign the samples
+            metadata (str): Optional JSON metadata to be applied to all samples
+        """
+
+        payload = {
+            "project_id": project_id,
+            "s3_uri": s3_uri,
+            "metadata": metadata,
+        }
+
+        return self._post(
+            self.endpoints.S3_URI_AUTOIMPORT.value,
+            payload,
+            authorized=True,
+            model=S3AutoimportTopic,
+        )
+
+    def list_s3_autoimport_jobs(self, next_link=None):
+        """Make a request to list S3 import jobs.
+
+        Args:
+            next_link (str, optional): url from previous
+                response['meta']['next'].
+
+        Returns:
+            api response (dict):
+                {
+                    "meta": {
+                        "count": int,
+                        "next": str,
+                        "previous": optional[str],
+                    },
+                    "results": [...]
+                }
+        """
+
+        params = self._add_query_params(next_link)
+        return self._get(
+            self.endpoints.S3_URI_AUTOIMPORT.value,
+            query_params=params,
+            authorized=True,
+            model=S3ProjectImport,
+        )
+
+    def delete_project_samples(self, project_id, sample_ids):
+        """Make a request to delete samples in given project.
+
+        Args:
+            project_id (str): project to which to assign the samples
+            sample_ids (list of strings): sample_ids to soft delete
+        """
+        delete_project_samples_endpoint = (
+            self.endpoints.PROJECT_DELETE_SAMPLES.value.format(id=project_id)
+        )
+
+        payload = {"sample_ids": sample_ids}
+
+        return self._delete(delete_project_samples_endpoint, payload, authorized=True)
+
+    def get_file_checksum(self, file_id, filename=None):
+        """Fetch file checksum, using the client because need to be
+        authenticated.
+        """
+        params = {}
+        if filename:
+            params["filename"] = filename
+        return self._get(
+            self.endpoints.FILE_CHECKSUM.value.format(id=file_id),
+            query_params=params,
+            authorized=True,
+            raw_response=True,
+        )
+
+    def import_existing_samples(self, project_id, sample_ids, metadata):
+        """Import existing samples to a project and pass metadata."""
+        payload = {
+            "project_id": project_id,
+            "samples": [{"sample_id": sample_id} for sample_id in sample_ids],
+        }
+        if metadata:
+            payload["metadata"] = metadata
+        return self._post(
+            self.endpoints.IMPORT_EXISTING_SAMPLES.value,
+            payload,
+            authorized=True,
+            model=ImportExistingSamplesModel,
+        )
+
+    def get_file_types(self, project_id=None):
+        """List file types.
+
+        Args:
+            project_id (UUID, optional): project_id used to get all file types
+                for a project
+        """
+        params = {}
+        if project_id:
+            params["project_id"] = project_id
+        return self._get(
+            self.endpoints.FILE_TYPES.value,
+            query_params=params,
+            authorized=True,
+            model=FileTypesModel,
+        )
