@@ -20,19 +20,22 @@ common_options = [  # pylint: disable=invalid-name
         "--email",
         default=lambda: os.environ.get("GENCOVE_EMAIL", ""),
         help="Gencove user email to be used in login. "
-        "Can be passed as GENCOVE_EMAIL environment variable",
+        "Can be passed as GENCOVE_EMAIL environment variable.",
     ),
     click.option(
         "--password",
         default=lambda: os.environ.get("GENCOVE_PASSWORD", ""),
         help="Gencove user password to be used in login. "
-        "Can be passed as GENCOVE_PASSWORD environment variable",
+        "Can be passed as GENCOVE_PASSWORD environment variable. "
+        "When MFA is configured, an MFA token will have to be provided after "
+        "the command is executed.",
     ),
     click.option(
         "--api-key",
         default=lambda: os.environ.get("GENCOVE_API_KEY", ""),
         help="Gencove api key. "
-        "Can be passed as GENCOVE_API_KEY environment variable",
+        "Can be passed as GENCOVE_API_KEY environment variable. "
+        "When using the API key, an MFA token does not need to be provided.",
     ),
 ]
 
