@@ -36,32 +36,25 @@ class CreateBatch(Command):
             ValidationError - if something is wrong with command parameters.
         """
         if not self.batch_type:
-            raise ValidationError(
-                "You must provide value for --batch-type. Exiting."
-            )
+            raise ValidationError("You must provide value for --batch-type. Exiting.")
 
         if not self.batch_name:
-            raise ValidationError(
-                "You must provide value for --batch-name. Exiting."
-            )
+            raise ValidationError("You must provide value for --batch-name. Exiting.")
 
         if is_valid_uuid(self.project_id) is False:
             raise ValidationError("Project ID is not valid. Exiting.")
 
         if self.sample_ids:
             if not all(is_valid_uuid(s_id) for s_id in self.sample_ids):
-                raise ValidationError(
-                    "Not all sample IDs are valid. Exiting."
-                )
+                raise ValidationError("Not all sample IDs are valid. Exiting.")
 
     # no retry for timeouts in order to avoid duplicate heavy operations on
     # the backend
     def execute(self):
         """Make a request to create a batch for given project."""
         self.echo_debug(
-            "Creating batch for project {} and batch key {}".format(
-                self.project_id, self.batch_name
-            )
+            f"Creating batch for project {self.project_id} and "
+            f"batch key {self.batch_name}"
         )
 
         try:
@@ -77,14 +70,10 @@ class CreateBatch(Command):
         except client.APIClientError as err:
             self.echo_debug(err)
             if err.status_code == 400:
-                self.echo_warning(
-                    "There was an error creating project batches."
-                )
+                self.echo_warning("There was an error creating project batches.")
                 self.echo_info("The following error was returned:")
                 self.echo_info(err.message)
             elif err.status_code == 404:
-                self.echo_warning(
-                    "Project {} does not exist.".format(self.project_id)
-                )
+                self.echo_warning(f"Project {self.project_id} does not exist.")
             else:
                 raise
