@@ -6,8 +6,6 @@ from gencove.client import APIClientError, APIClientTimeout  # noqa: I100
 from gencove.command.base import Command
 
 from .utils import get_line
-from ...utils import is_valid_uuid
-from ....exceptions import ValidationError
 
 
 class ListSamples(Command):
@@ -26,17 +24,13 @@ class ListSamples(Command):
 
     def validate(self):
         """Validate command input."""
-        if is_valid_uuid(self.project_id) is False:
-            raise ValidationError("Project ID is not valid. Exiting.")
 
     def execute(self):
         self.echo_debug(
             "Retrieving sample sheet: "
-            "status={} archive_status={} search_term={}".format(
-                self.sample_status,
-                self.sample_archive_status,
-                self.search_term,
-            )
+            f"status={self.sample_status} "
+            f"archive_status={self.sample_archive_status} "
+            f"search_term={self.search_term}"
         )
         try:
             for samples in self.get_paginated_samples():
@@ -48,9 +42,7 @@ class ListSamples(Command):
                     self.echo_data(get_line(sample))
         except APIClientError as err:
             if err.status_code == 404:
-                self.echo_error(
-                    "Project {} does not exist.".format(self.project_id)
-                )
+                self.echo_error(f"Project {self.project_id} does not exist.")
             raise
 
     def get_paginated_samples(self):
