@@ -65,29 +65,28 @@ def upload(  # pylint: disable=E0012,C0330,R0913
             gencove upload test_dataset gncv://test
 
     \f
+    .. ignore::
+        Args:
+            source (.fastq.gz, .fastq.bgz, .fq.gz, .fq.bgz):
+                folder that contains fastq files to be uploaded
+                OR .fastq-map.csv file
+            destination (str, optional): 'gncv://' notated folder
+                on Gencove's system, where the files will be uploaded to.
+            run_project_id (UUID, optional): ID of a project to which all files
+                in this upload will be assigned to and then immediately analyzed.
+            output (str, optional): must be used with run_project_id. "-"
+                redirects the JSON to STDOUT, and a name redirects the output to
+                a file.
+            no_progress (bool, optional, default False): do not show progress
+                bar.
+            metadata (str, optional): JSON metadata to be applied to all samples
 
-    Args:
-        source (.fastq.gz, .fastq.bgz, .fq.gz, .fq.bgz):
-            folder that contains fastq files to be uploaded
-            OR .fastq-map.csv file
-        destination (str, optional): 'gncv://' notated folder
-            on Gencove's system, where the files will be uploaded to.
-        run_project_id (UUID, optional): ID of a project to which all files
-            in this upload will be assigned to and then immediately analyzed.
-        output (str, optional): must be used with run_project_id. "-"
-            redirects the JSON to STDOUT, and a name redirects the output to
-            a file.
-        no_progress (bool, optional, default False): do not show progress
-            bar.
-        metadata (str, optional): JSON metadata to be applied to all samples
     """
     Upload(
         source,
         destination,
         Credentials(email=email, password=password, api_key=api_key),
-        UploadOptions(
-            host=host, project_id=run_project_id, metadata=metadata
-        ),
+        UploadOptions(host=host, project_id=run_project_id, metadata=metadata),
         output,
         no_progress,
     ).run()
