@@ -26,7 +26,17 @@ class ApiEndpoints(Enum):
     BATCHES = "/api/v2/batches/{id}"
     PROJECT_MERGE_VCFS = "/api/v2/project-merge-vcfs/{id}"
     SAMPLE_METADATA = "/api/v2/sample-metadata/{id}"
+    PROJECT_DELETE_SAMPLES = "/api/v2/project-delete-samples/{id}"
     PROJECT_RESTORE_SAMPLES = "/api/v2/project-restore-samples/{id}"
+    BASESPACE_PROJECTS_IMPORT = "/api/v2/basespace-projects-import/"
+    BASESPACE_PROJECTS_LIST = "/api/v2/basespace-projects/"
+    BASESPACE_BIOSAMPLES_LIST = "/api/v2/basespace-project-biosamples/{id}"
+    S3_URI_IMPORT = "/api/v2/s3-uri-import/"
+    BASESPACE_PROJECTS_AUTOIMPORT = "/api/v2/basespace-projects-autoimport/"
+    S3_URI_AUTOIMPORT = "/api/v2/s3-uri-autoimport/"
+    FILE_CHECKSUM = "/api/v2/files/{id}.sha256"
+    IMPORT_EXISTING_SAMPLES = "/api/v2/project-samples-import/"
+    FILE_TYPES = "/api/v2/file-types/"
 
 
 @unique
@@ -65,6 +75,7 @@ class SampleArchiveStatus(Enum):
     ARCHIVED = "archived"
     RESTORE_REQUESTED = "restore_requested"
     ALL = "all"
+    UNKNOWN = "unknown"
 
 
 @unique
@@ -93,6 +104,7 @@ class Credentials(BaseModel):
     email: str
     password: str
     api_key: str
+    otp_token: Optional[str] = None
 
 
 # pylint: disable=too-few-public-methods
@@ -113,10 +125,10 @@ class DownloadTemplateParts(Enum):
     DEFAULT_FILENAME = "default_filename"
 
 
-DOWNLOAD_TEMPLATE = "{{{}}}/{{{}}}/{{{}}}".format(
-    DownloadTemplateParts.CLIENT_ID.value,
-    DownloadTemplateParts.GENCOVE_ID.value,
-    DownloadTemplateParts.DEFAULT_FILENAME.value,
+DOWNLOAD_TEMPLATE = (
+    f"{{{DownloadTemplateParts.CLIENT_ID.value}}}/"
+    f"{{{DownloadTemplateParts.GENCOVE_ID.value}}}/"
+    f"{{{DownloadTemplateParts.DEFAULT_FILENAME.value}}}"
 )
 
 MAX_RETRY_TIME_SECONDS = 300  # 5 minutes
